@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::NodeViewer;
-$Config::Model::Tk::NodeViewer::VERSION = '1.348';
+$Config::Model::Tk::NodeViewer::VERSION = '1.349';
 use strict;
 use warnings;
 use Carp;
@@ -43,7 +43,7 @@ sub Populate {
 
     my $elt_frame = $cw->Frame(qw/-relief flat/)->pack(@fbe1);
 
-    $elt_frame->Label( -text => $node->composite_name . ' node elements' )->pack();
+    $elt_frame->Label( -text => $node->composite_name_short . ' node elements' )->pack();
 
     my $hl = $elt_frame->Scrolled(
         'HList',
