@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.348';
+$Config::Model::TkUI::VERSION = '1.349';
 use 5.10.1;
 use strict;
 use warnings;
@@ -493,6 +493,9 @@ sub quit {
             $cw->show_changes( sub { $cw->quit } );
         }
     }
+    else {
+        $cw->self_destroy;
+    }
 
 }
 
@@ -567,7 +570,7 @@ sub update_loc_bar {
     #$cw->{path}=$path ;
     my $datar = $cw->{tktree}->infoData($path);
     my $obj   = $datar->[1];
-    $cw->{location} = $obj->location;
+    $cw->{location} = $obj->location_short;
 }
 
 sub on_select {
@@ -617,7 +620,6 @@ sub on_cut_buffer_dump {
 
 # replace dot in str by _|_
 sub to_path   { my $str  = shift; $str =~ s/\./_|_/g; return $str; }
-sub from_path { my $path = shift; $path =~ s/_|_/./g; return $path; }
 
 sub force_element_display {
     my $cw      = shift;
@@ -778,7 +780,7 @@ sub disp_hash {
             my @data = ( $scan_sub, $sub_elt );
             weaken( $data[1] );
             $tkt->add( $newpath, -data => \@data, @opt );
-            $tkt->itemCreate( $newpath, 0, -text => $idx );
+            $tkt->itemCreate( $newpath, 0, -text => $node->shorten_idx($idx) );
             $tkt->setmode( $newpath => $eltmode );
         }
 
@@ -786,6 +788,7 @@ sub disp_hash {
         $elt_loc .= ' ' if $elt_loc;
 
         # need to keep regexp identical to the one from C::M::Anything:composite_name
+        # so that force_display_path (aka fd_path may work)
         $elt_loc .= $element_name . ':' . ( $idx =~ /\W/ ? '"' . $idx . '"' : $idx );
 
         # hide new entry if hash is not yet opened
